from core import Request, BankNodeConfig, Response
from bank_protocol.exceptions import InvalidRequest
from services.account_service import delete_account
from bank_protocol.proxy_handler import BankProxy


def account_remove(request: Request, config: BankNodeConfig) -> Response:
    if request.body is None:
        raise InvalidRequest("Invalid request format")

    try:
        split_body = request.body.split("/")

        account = split_body[0]
        ip = split_body[1]

    except IndexError as e:
        raise InvalidRequest("Invalid request format") from e

    if ip != config.ip:
        bank_proxy = BankProxy(request, ip, config)
        return bank_proxy.proxy_request()

    if not account.isdigit():
        raise InvalidRequest("Account must be a number")

    account_parsed = int(account)

    if account_parsed < 10_000 or account_parsed > 99_999:
        raise InvalidRequest("Account number out of range")

    delete_account(account_parsed)

    return "AR"


__all__ = ["account_remove"]
