import logging
import threading

from core import Request, Response, BankNodeConfig
from core.peer import BankPeer
from bank_protocol.exceptions import NoPortsOpenError
from bank_protocol.bank_scanner import BankScanner


class BankProxy():
    def __init__(self, request: Request, host: str, config: BankNodeConfig):
        self.request = request
        self.host = host
        self.config = config

        self.peer = BankPeer(self.host, None, None)
        self.bank_found_event = threading.Event()
        self.lock = threading.Lock()

        self.logger = logging.getLogger(__name__)
        self.logger.info("Proxying request")

    def proxy_request(self) -> Response:
        scanner_threads = []

        for port in range(self.config.scan_port_start, self.config.scan_port_end + 1):
            if self.bank_found_event.is_set():
                break

            t = BankScanner(self.host, port, self.peer, self.bank_found_event, self.lock, self.config.timeout)
            t.start()
            scanner_threads.append(t)

        for t in scanner_threads:
            t.join()

        if not self.bank_found_event.is_set():
            self.logger.warning("No bank application found on host %s", self.host)
            raise NoPortsOpenError("Bank is unreachable")

        # with self.peer.bank_socket as bank_socket:
        self.peer.bank_socket.sendall((str(self.request) + "\r\n").encode("utf-8"))
        response = self.peer.bank_socket.recv(1024).decode("utf-8")

        return response
